
import React, { Suspense } from 'react';
import { BrowserRouter as Router, Routes, Route, Navigate } from 'react-router-dom';
import { HelmetProvider } from 'react-helmet-async';
import { Toaster } from 'sonner';
import { QueryClient, QueryClientProvider } from '@tanstack/react-query';
import { UserProvider } from './contexts/UserContext';
import { Spinner } from "@/components/ui/spinner";

// Eager load critical components
import Home from './pages/Home';
import FindInternships from './pages/FindInternships';
import InternshipDetail from './pages/InternshipDetail';
import Sitemap from './pages/Sitemap';

// Lazy load non-critical components
const About = React.lazy(() => import('./pages/About'));
const Contact = React.lazy(() => import('./pages/Contact'));
const Features = React.lazy(() => import('./pages/Features'));
const Pricing = React.lazy(() => import('./pages/Pricing'));
const Media = React.lazy(() => import('./pages/Media'));
const Salaries = React.lazy(() => import('./pages/Salaries'));
const AIResumeTips = React.lazy(() => import('./pages/AIResumeTips'));
const FreeAIResumeReview = React.lazy(() => import('./pages/FreeAIResumeReview'));
const AICoverLetterGenerator = React.lazy(() => import('./pages/AICoverLetterGenerator'));
const PrivacyPolicy = React.lazy(() => import('./pages/PrivacyPolicy'));
const TermsOfService = React.lazy(() => import('./pages/TermsOfService'));
const PostInternship = React.lazy(() => import('./pages/PostInternship'));
const PostJob = React.lazy(() => import('./pages/PostJob'));
const TalentBoard = React.lazy(() => import('./pages/TalentBoard'));
const NotFound = React.lazy(() => import('./pages/NotFound'));
const Auth = React.lazy(() => import('./pages/Auth'));
const Profile = React.lazy(() => import('./pages/Profile'));
const EnterpriseSolutions = React.lazy(() => import('./pages/EnterpriseSolutions'));
const SwipeInternshipsPage = React.lazy(() => import('./pages/SwipeInternshipsPage'));
const SavedInternshipsPage = React.lazy(() => import('./pages/SavedInternshipsPage'));
const Account = React.lazy(() => import('./pages/Account'));
const AccountSettingsPage = React.lazy(() => import('./pages/AccountSettingsPage'));
const AdminDashboard = React.lazy(() => import('./pages/admin/Dashboard'));
const BlogRouter = React.lazy(() => import('./components/BlogRouter'));
const InterviewPrepper = React.lazy(() => import('./pages/InterviewPrepper'));
const AIInterviewPrepper = React.lazy(() => import('./pages/AIInterviewPrepper'));
const AIInterviewBuddy = React.lazy(() => import('./pages/AIInterviewBuddy'));

// Create a client with improved configuration
const queryClient = new QueryClient({
  defaultOptions: {
    queries: {
      staleTime: 5 * 60 * 1000, // 5 minutes
      retry: 1,
      refetchOnWindowFocus: false,
      refetchOnMount: true, // Ensure data is fresh when mounting components
    },
  },
});

const LoadingFallback = () => (
  <div className="flex items-center justify-center min-h-screen">
    <Spinner size="lg" />
  </div>
);

// Custom component to handle direct redirect to XML sitemap
const XMLSitemapRedirect = () => {
  React.useEffect(() => {
    window.location.href = 'https://cxdkahbjxbvetoxgpvge.supabase.co/functions/v1/sitemap-xml';
  }, []);
  
  return null;
};

function App() {
  return (
    <QueryClientProvider client={queryClient}>
      <HelmetProvider>
        <Router>
          <UserProvider>
            <Toaster position="bottom-right" richColors />
            <Suspense fallback={<LoadingFallback />}>
              <Routes>
                <Route path="/" element={<Home />} />
                <Route path="/find-ai-internships" element={<FindInternships />} />
                {/* Redirect old URL to new one */}
                <Route path="/find-internships" element={<Navigate to="/find-ai-internships" replace />} />
                <Route path="/internship/:id" element={<InternshipDetail />} />
                <Route path="/about" element={<About />} />
                <Route path="/about-us" element={<About />} />
                <Route path="/contact" element={<Contact />} />
                <Route path="/features" element={<Features />} />
                <Route path="/pricing" element={<Pricing />} />
                {/* Redirect old media URL to new blog URL */}
                <Route path="/media" element={<Navigate to="/blog" replace />} />
                <Route path="/blog" element={<Media />} />
                
                {/* Blog routes - consistent approach using BlogRouter for all */}
                <Route path="/blog/*" element={<BlogRouter />} />
                
                {/* New AI salaries URL */}
                <Route path="/ai-salaries" element={<Salaries />} />
                {/* Redirect old salaries URLs to new one */}
                <Route path="/ai-salaries-trends" element={<Navigate to="/ai-salaries" replace />} />
                <Route path="/salaries" element={<Navigate to="/ai-salaries" replace />} />
                
                <Route path="/ai-resume-tips" element={<AIResumeTips />} />
                <Route path="/free-ai-resume-review" element={<FreeAIResumeReview />} />
                <Route path="/ai-cover-letter-generator" element={<AICoverLetterGenerator />} />
                <Route path="/privacy-policy" element={<PrivacyPolicy />} />
                <Route path="/terms-of-service" element={<TermsOfService />} />
                <Route path="/post-internship" element={<PostInternship />} />
                <Route path="/post-job" element={<PostJob />} />
                <Route path="/talent-board" element={<TalentBoard />} />
                <Route path="/auth" element={<Auth />} />
                <Route path="/profile" element={<Profile />} />
                <Route path="/enterprise-solutions" element={<EnterpriseSolutions />} />
                <Route path="/swipe-internships" element={<SwipeInternshipsPage />} />
                <Route path="/saved-internships" element={<SavedInternshipsPage />} />
                <Route path="/account" element={<Account />} />
                <Route path="/account-settings" element={<AccountSettingsPage />} />
                <Route path="/interview-prepper" element={<InterviewPrepper />} />
                <Route path="/ai-interview-prepper" element={<AIInterviewPrepper />} />
                <Route path="/ai-interview-buddy" element={<AIInterviewBuddy />} />
                <Route path="/admin/dashboard" element={<AdminDashboard />} />
                
                {/* XML Sitemap - direct redirect to edge function */}
                <Route path="/sitemap.xml" element={<XMLSitemapRedirect />} />
                
                {/* HTML Sitemap for users - moved to new URL */}
                <Route path="/sitemap" element={<Sitemap />} />
                
                <Route path="*" element={<NotFound />} />
              </Routes>
            </Suspense>
          </UserProvider>
        </Router>
      </HelmetProvider>
    </QueryClientProvider>
  );
}

export default App;
